==> kissd-0.12.tar.bz2: kissd-0.12/kissd.h <==
/*
 * kissd - KiSS PC-Link Daemon
 *
 * Copyright (C) 2005 Stelian Pop <stelian@popies.net>
 *
 * Heavily based on kiss4lin,
 * Copyright (C) 2004 Jacob Kolding <dacobi@users.sourceforge.net>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2, or (at your option)
 * any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 *
 */

#include <syslog.h>

extern int a_opt, d_opt, k_opt, v_opt;

extern char audiopath[];
extern char videopath[];
extern char picturepath[];
extern char kmlurl[];
extern char pretrigger[];
extern char posttrigger[];
extern int max_recent_files;

#define KISSD_VERSION "version 0.12, Sep 23, 2006"

void handle_request(int sock);
void handle_kmlrequest(int sock);
void clean_pathname(char *path);
int handle_playlist(int sock, char *filename);
int do_send(int sock, char *buf, int len);
#if defined(USE_INTERNAL_SENDFILE_COPY) || defined(USE_INTERNAL_SENDFILE_MMAP)
#define USE_INTERNAL_SENDFILE
ssize_t internal_sendfile(int dst, int src, off_t *offset, size_t size);
#endif



#define log(format, args...)					\
	do {							\
		if (d_opt)					\
			syslog(LOG_WARNING, format, args);	\
		else						\
			fprintf(stderr, format "\n", args);	\
	} while(0)

#define logv(format, args...)					\
	do {							\
		if (v_opt) {					\
			if (d_opt)				\
				syslog(LOG_WARNING, format, args);\
			else					\
				fprintf(stderr, format "\n", args);\
		}						\
	} while(0)

#define min(a, b) (((a) < (b)) ? (a) : (b))
#define max(a, b) (((a) > (b)) ? (a) : (b))

==> kissd-0.13.tar.bz2: kissd-0.13/kissd.h <==
/*
 * kissd - KiSS PC-Link Daemon
 *
 * Copyright (C) 2005 Stelian Pop <stelian@popies.net>
 *
 * Heavily based on kiss4lin,
 * Copyright (C) 2004 Jacob Kolding <dacobi@users.sourceforge.net>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2, or (at your option)
 * any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 *
 */

#include <syslog.h>

extern int a_opt, d_opt, k_opt, v_opt;

extern char audiopath[];
extern char videopath[];
extern char picturepath[];
extern char kmlurl[];
extern char pretrigger[];
extern char posttrigger[];
extern int max_recent_files;

#define KISSD_VERSION "version 0.13, Oct 15, 2006"

const char* convert_charset (const char* s);

void handle_request(int sock);
void handle_kmlrequest(int sock);
void clean_pathname(char *path);
int handle_playlist(int sock, char *filename);
int do_send(int sock, char *buf, int len);
#if defined(USE_INTERNAL_SENDFILE_COPY) || defined(USE_INTERNAL_SENDFILE_MMAP)
#define USE_INTERNAL_SENDFILE
ssize_t internal_sendfile(int dst, int src, off_t *offset, size_t size);
#endif



#define log(format, args...)					\
	do {							\
		if (d_opt)					\
			syslog(LOG_WARNING, format, args);	\
		else						\
			fprintf(stderr, format "\n", args);	\
	} while(0)

#define logv(format, args...)					\
	do {							\
		if (v_opt) {					\
			if (d_opt)				\
				syslog(LOG_WARNING, format, args);\
			else					\
				fprintf(stderr, format "\n", args);\
		}						\
	} while(0)

#define min(a, b) (((a) < (b)) ? (a) : (b))
#define max(a, b) (((a) > (b)) ? (a) : (b))
